class NodeDashboard {
  constructor() {
    this.workspace = document.getElementById('workspace');
    this.modal = document.getElementById('editModal');
    this.currentNode = null;
    this.isDragging = false;
    this.initialX = 0;
    this.initialY = 0;
    this.xOffset = 0;
    this.yOffset = 0;
    
    this.init();
  }

  init() {
    this.setupEventListeners();
    this.setupWorkspaceRotation();
  }

  setupEventListeners() {
    document.getElementById('addNode').addEventListener('click', () => this.createNode());
    document.getElementById('resetView').addEventListener('click', () => this.resetView());
    document.getElementById('saveNode').addEventListener('click', () => this.saveNodeEdit());
    document.getElementById('cancelEdit').addEventListener('click', () => this.closeModal());
  }

  setupWorkspaceRotation() {
    let rotateX = 0;
    let rotateY = 0;

    this.workspace.addEventListener('mousemove', (e) => {
      if (!this.isDragging) {
        rotateY = (e.clientX - window.innerWidth / 2) * 0.02;
        rotateX = (e.clientY - window.innerHeight / 2) * -0.02;
        this.workspace.style.transform = `rotateX(${rotateX}deg) rotateY(${rotateY}deg)`;
      }
    });
  }

  createNode(x = Math.random() * 500, y = Math.random() * 300) {
    const node = document.createElement('div');
    node.className = 'node';
    node.innerHTML = `
      <h3>New Node</h3>
      <p>Double-click to edit</p>
    `;
    node.style.transform = `translate(${x}px, ${y}px)`;
    
    this.setupNodeEvents(node);
    this.workspace.appendChild(node);
  }

  setupNodeEvents(node) {
    node.addEventListener('mousedown', (e) => this.dragStart(e, node));
    node.addEventListener('dblclick', () => this.editNode(node));
    node.addEventListener('contextmenu', (e) => {
      e.preventDefault();
      node.remove();
    });

    document.addEventListener('mousemove', (e) => this.drag(e));
    document.addEventListener('mouseup', () => this.dragEnd());
  }

  dragStart(e, node) {
    if (e.button !== 0) return;
    this.isDragging = true;
    this.currentNode = node;
    
    const transform = window.getComputedStyle(node).transform;
    const matrix = new DOMMatrix(transform);
    this.xOffset = matrix.m41;
    this.yOffset = matrix.m42;
    
    this.initialX = e.clientX - this.xOffset;
    this.initialY = e.clientY - this.yOffset;
  }

  drag(e) {
    if (!this.isDragging) return;
    e.preventDefault();
    
    const currentX = e.clientX - this.initialX;
    const currentY = e.clientY - this.initialY;
    
    this.currentNode.style.transform = `translate(${currentX}px, ${currentY}px)`;
  }

  dragEnd() {
    this.isDragging = false;
    this.currentNode = null;
  }

  editNode(node) {
    this.currentNode = node;
    document.getElementById('nodeTitle').value = node.querySelector('h3').textContent;
    document.getElementById('nodeContent').value = node.querySelector('p').textContent;
    this.modal.style.display = 'block';
  }

  saveNodeEdit() {
    const title = document.getElementById('nodeTitle').value;
    const content = document.getElementById('nodeContent').value;
    
    this.currentNode.querySelector('h3').textContent = title;
    this.currentNode.querySelector('p').textContent = content;
    
    this.closeModal();
  }

  closeModal() {
    this.modal.style.display = 'none';
    this.currentNode = null;
  }

  resetView() {
    this.workspace.style.transform = 'rotateX(0deg) rotateY(0deg)';
  }
}

document.addEventListener('DOMContentLoaded', () => {
  const dashboard = new NodeDashboard();
});
